@@ -9,9 +9,11 @@ from .api import (  # noqa:F401
     download_chemreps,
     download_extract_sqlite,
     download_fps,
+    download_monomer_library,
     download_sdf,
     download_sqlite,
     get_chemreps_df,
+    get_monomer_library_root,
     get_substructure_library,
     latest,
     query,
